function nucleiPositions = BONucleiDetector3D(imageNuclei, imageMembrane, nucleiSize, thValue, resolutionXY, resolutionZ, scaleXY, scaleZ)
%%  BONucleiDetector3D - Automatic 3D Nuclei Detector
%       
%        We start with a laser scanning confocal 3D stack that has a nuclear stain channel.
%   INPUT:
%       imageNuclei, imageMembrane  - Channels are selected by number and nuclear channel must to be present. You can also select a membrane channel if it exists, this could help to filter out incorrectly detected centroids.
%       nucleiSize                  - nuclei size: We have approximately measured the size of the nucleus and obtained 3 microns. This value we will enter as "Nuclei Size" parameter.
%       thValue                     - low intensity bound: We would also like to reject 20% of lower intensity levels as a valid response of a nuclei, so we set 0.2 as a "Low intensity level".
%       resolutionXY, resolutionZ, scaleXY, scaleZ 
%                                   - pixel size: If the image has embedded meta-data then both pixel resolution X/Y and Z will be filled automatically. If you would want to change these values, they will be stored in the appropriate image tag and preserved.
%   OUTPUT:
%       nucleiPositions             - detected nuclei positions
%
% 
%   Boguslaw Obara, http://boguslawobara.net/
%
%   Version:
%       0.1 - 16/04/2008 First implementation
%       0.11- 16/08/2008 Testing

%%
%% LoG
[imageSeeds nucleiPositions] = BOLoGDetector3D(imageNuclei, nucleiSize, resolutionXY, resolutionZ, scaleXY, scaleZ, thValue);
%% Filtering
descriptorTable = BO3DMaskDescriptor(imageNuclei, nucleiPositions, nucleiSize, resolutionXY, resolutionZ, scaleXY, scaleZ);
if isempty(imageMembrane)
    nucleiPositions = BO3DProfileDescriptor(imageMembrane, nucleiPositions, descriptorTable, nucleiSize*1.5, resolutionXY, resolutionZ, scaleXY, scaleZ);
else
    nucleiPositions = BO3DStatDescriptor(imageNuclei, nucleiPositions, descriptorTable, nucleiSize*1.5, resolutionXY, resolutionZ, scaleXY, scaleZ);
end
%%
end      
